APEv2
=====

.. automodule:: mutagen.apev2


APEv2
-----

.. autoexception:: mutagen.apev2.error

.. autoexception:: mutagen.apev2.APENoHeaderError

.. autoexception:: mutagen.apev2.APEUnsupportedVersionError

.. autoexception:: mutagen.apev2.APEBadItemError

.. autoclass:: mutagen.apev2.APEv2File(filename)
    :show-inheritance:
    :members:
    :undoc-members:

.. autoclass:: mutagen.apev2.APEv2
    :show-inheritance:
    :members:


Musepack
--------

.. automodule:: mutagen.musepack

.. autoclass:: mutagen.musepack.Musepack
    :show-inheritance:
    :members:

.. autoclass:: mutagen.musepack.MusepackInfo
    :members:


WavPack
-------

.. automodule:: mutagen.wavpack

.. autoclass:: mutagen.wavpack.WavPack
    :show-inheritance:
    :members:

.. autoclass:: mutagen.wavpack.WavPackInfo
    :members:


Monkey's Audio
--------------

.. automodule:: mutagen.monkeysaudio

.. autoclass:: mutagen.monkeysaudio.MonkeysAudio
    :show-inheritance:
    :members:

.. autoclass:: mutagen.monkeysaudio.MonkeysAudioInfo
    :members:


OptimFROG
---------

.. automodule:: mutagen.optimfrog

.. autoclass:: mutagen.optimfrog.OptimFROG
    :show-inheritance:
    :members:

.. autoclass:: mutagen.optimfrog.OptimFROGInfo
    :members:
